@@ -952,8 +952,11 @@ def setup():
     glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST)
     setup_fog()
 
-
 def main():
+    w = World("DEMO")
+    w.run()
+
+def demo():
     from pyblockworld import World
 
     #
